#! /usr/bin/env python 
# -*- coding: utf-8 -*-
# by Hans Schou <chlor@schou.dk> 2014-01-15
#
# Syntax example:
#   ./svg.py > python.svg

import math, sys

# In the code the term 'fraction' is equal
# to a fraction of a cicle. Fraction = 1 = 360° = 2*pi
# A 'fraction' can be converted to radians by multiply with 2π.

toothCount = 8
RADIUS = 300.0
radius = RADIUS * 3/4
innerRad = RADIUS * 9/32 # aprx ~ 1/4
angelStart = 1.0/4 + 1.0/(toothCount*2)
angelToothTop = 1.0/(toothCount*3)
angelToothBottom = 1.0/(toothCount*3)
angelToothEdge = (1.0/toothCount - angelToothTop - angelToothBottom) / 2

vectorsTooth = [ {"rad":RADIUS, "ang":angelToothEdge}, {"rad":RADIUS, "ang":angelToothTop}, {"rad":radius, "ang":angelToothEdge} ];

def polarGearLogo():
	angel = angelStart
	p = []
	p.append( dictRadFraction(innerRad, angel) )
	p.append( dictRadFraction(radius, angel) )
	# Draw half tooth space
	angel += angelToothBottom / 2
	p.append( dictRadFraction(radius, angel) )
	n = toothCount - 1 # one tooth is missing on the gear
	while (n > 0):
		# Draw one tooth on the gear
		for pnt in vectorsTooth:
			angel += pnt['ang']
			p.append( dictRadFraction(pnt['rad'], angel) )
		# Draw one space between 2 tooths, or if last point draw a half space
		angel += angelToothBottom / (1 if n > 1 else 2)
		p.append( dictRadFraction(radius, angel) )
		n -= 1
	p.append( dictRadFraction(radius, angel) )
	# Draw inner circle counter clock wise
	p.append( dictRadFraction(innerRad, angel) )
	toothDiv = 3
	n = (toothCount-1)*toothDiv
	while (n > 0):
		angel -= 1.0/(toothCount*toothDiv)
		p.append( dictRadFraction(innerRad, angel) )
		n -= 1
	return p

# Convert radius and fraction to dictionary
# Return dictionary of 'r' and 'f'
def dictRadFraction(rad, fract):
	return { "r": rad, "f": fract }

# Vector in polar coordinate to cartesian coordinate
# Note: The angel is a fraction of a cicle not radians
# Return: Cartesian coordinates dictionary
def polarToCartesian(polar, offset):
	c = []
	for pol in polar:
		c.append( {"x": offset['x'] + pol['r'] * math.cos(pol['f'] * math.pi*2), "y": -1 * (offset['y'] + pol['r'] * math.sin(pol['f'] * math.pi*2))} );
	return c

polar = polarGearLogo()
cartesian = polarToCartesian(polar, {'x':RADIUS,'y':RADIUS})
s = "static const struct { int x; int y; } drawing[] = {\n"
pre = { "x": 0, "y": 0 }
pre = cartesian.pop(0)
for pnt in cartesian:
	s += "\t{ %d, %d },\n" % (round(pre['x']-pnt['x']), round(pre['y']-pnt['y']))
	pre = pnt
s += "};\n"
print s

